@@ -1,10 +1,9 @@
 # Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
-import os
 
 from qtpy.QtDesigner import QDesignerCustomWidgetInterface
+from qtpy.QtWidgets import QWidget
 
-import bec_widgets
 from bec_widgets.utils.bec_designer import designer_material_icon
 from bec_widgets.widgets.progress.ring_progress_bar.ring_progress_bar import RingProgressBar
 
@@ -14,7 +13,6 @@ DOM_XML = """
     </widget>
 </ui>
 """
-MODULE_PATH = os.path.dirname(bec_widgets.__file__)
 
 
 class RingProgressBarPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
@@ -23,6 +21,8 @@ class RingProgressBarPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
         self._form_editor = None
 
     def createWidget(self, parent):
+        if parent is None:
+            return QWidget()
         t = RingProgressBar(parent)
         return t
 
@@ -51,7 +51,7 @@ class RingProgressBarPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
         return "RingProgressBar"
 
     def toolTip(self):
-        return "RingProgressBar"
+        return ""
 
     def whatsThis(self):
         return self.toolTip()
