@@ -1,10 +1,9 @@
 # Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
-import os
 
 from qtpy.QtDesigner import QDesignerCustomWidgetInterface
+from qtpy.QtWidgets import QWidget
 
-import bec_widgets
 from bec_widgets.utils.bec_designer import designer_material_icon
 from bec_widgets.widgets.utility.toggle.toggle import ToggleSwitch
 
@@ -15,8 +14,6 @@ DOM_XML = """
 </ui>
 """
 
-MODULE_PATH = os.path.dirname(bec_widgets.__file__)
-
 
 class ToggleSwitchPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
     def __init__(self):
@@ -24,6 +21,8 @@ class ToggleSwitchPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
         self._form_editor = None
 
     def createWidget(self, parent):
+        if parent is None:
+            return QWidget()
         t = ToggleSwitch(parent)
         return t
 
@@ -52,7 +51,7 @@ class ToggleSwitchPlugin(QDesignerCustomWidgetInterface):  # pragma: no cover
         return "ToggleSwitch"
 
     def toolTip(self):
-        return "ToggleSwitch"
+        return ""
 
     def whatsThis(self):
         return self.toolTip()
