@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 
 from qtpy.QtDesigner import QDesignerCustomWidgetInterface
+from qtpy.QtWidgets import QWidget
 
 from bec_widgets.utils.bec_designer import designer_material_icon
 from bec_widgets.widgets.utility.visual.colormap_widget.colormap_widget import BECColorMapWidget
@@ -20,6 +21,8 @@ class BECColorMapWidgetPlugin(QDesignerCustomWidgetInterface):  # pragma: no cov
         self._form_editor = None
 
     def createWidget(self, parent):
+        if parent is None:
+            return QWidget()
         t = BECColorMapWidget(parent)
         return t
 
@@ -27,7 +30,7 @@ class BECColorMapWidgetPlugin(QDesignerCustomWidgetInterface):  # pragma: no cov
         return DOM_XML
 
     def group(self):
-        return "BEC Buttons"
+        return "BEC Visual Utils"
 
     def icon(self):
         return designer_material_icon(BECColorMapWidget.ICON_NAME)
